require 'test_helper'

class LimitsTest < Test::Unit::TestCase
  def setup
    super
    @header_hash = { 'X-DuoDealer-Shop-Api-Call-Limit' => '100/300' }
    DuodealerAPI::Base.connection.expects(:response).at_least(0).returns(@header_hash)
  end

  context "Limits" do
    should "fetch limit total" do
      assert_equal(299, DuodealerAPI.credit_limit(:shop))
    end

    should "fetch used calls" do
      assert_equal(100, DuodealerAPI.credit_used(:shop))
    end

    should "calculate remaining calls" do
      assert_equal(199, DuodealerAPI.credit_left)
    end

    should "flag maxed out credits" do
      assert !DuodealerAPI.maxed?
      @header_hash = { 'X-DuoDealer-Shop-Api-Call-Limit' => '299/300' }
      DuodealerAPI::Base.connection.expects(:response).at_least(1).returns(@header_hash)
      assert DuodealerAPI.maxed?
    end

    should "raise error when header doesn't exist" do
      @header_hash = {}
      DuodealerAPI::Base.connection.expects(:response).at_least(1).returns(@header_hash)
      assert_raises DuodealerAPI::Limits::LimitUnavailable do
        DuodealerAPI.credit_left
      end
    end
  end
end
