require 'rubygems'
require 'minitest/autorun'
require 'webmock/minitest'
require_relative 'lib/webmock_extensions/last_request'
require 'mocha/setup'
require 'pry'

$LOAD_PATH.unshift(File.dirname(__FILE__))
$LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))

WebMock.disable_net_connect!
require 'duodealer_api'

# setup DuodealerAPI with fake api_key and secret
module Test
  module Unit
    class TestCase < Minitest::Test
      def self.test(string, &block)
        define_method("test_#{string}", &block)
      end

      def self.should(string, &block)
        self.test("should_#{string}", &block)
      end

      def self.context(string)
        yield
      end

      def setup
        ActiveResource::Base.format = :json
        DuodealerAPI.constants.each do |const|
          begin
            const = mod.const_get(const)
            const.format = :json if const.respond_to?(:format=)
          rescue NameError
          end
        end

        DuodealerAPI::Base.clear_session

        fake("apis",
              url: "https://app.duodealer.com/services/apis.json",
              method: :get,
              status: 200,
              api_version: :stub,
              body: load_fixture('apis'))

        DuodealerAPI::ApiVersion.fetch_known_versions
        session = DuodealerAPI::Session.new(
          domain: "https://this-is-my-test-shop.duodealer.com",
          token: "token_test_helper",
          api_version: '2019-01',
        )

        DuodealerAPI::Base.activate_session(session)
      end

      def teardown
        DuodealerAPI::Base.clear_session
        DuodealerAPI::Base.site = nil
        DuodealerAPI::Base.password = nil
        DuodealerAPI::Base.user = nil

        DuodealerAPI::ApiVersion.clear_known_versions
        DuodealerAPI::ApiVersion.version_lookup_mode = :raise_on_unknown
      end

      # Custom Assertions
      def assert_not(expression)
        refute expression, "Expected <#{expression}> to be false!"
      end

      def assert_nothing_raised
        yield
      end

      def assert_not_includes(array, value)
        refute array.include?(value)
      end

      def assert_includes(array, value)
        assert array.include?(value)
      end

      def load_fixture(name, format=:json)
        File.read(File.dirname(__FILE__) + "/fixtures/#{name}.#{format}")
      end

      def assert_request_body(expected)
        assert_equal expected, WebMock.last_request.body
      end

      def fake(endpoint, options={})
        request_body = options.has_key?(:request_body) ? options.delete(:request_body) : nil
        body   = options.has_key?(:body) ? options.delete(:body) : load_fixture(endpoint)
        format = options.delete(:format) || :json
        method = options.delete(:method) || :get
        api_version = options.delete(:api_version) || DuodealerAPI::ApiVersion.find_version('2019-01')
        extension = ".#{options.delete(:extension)||'json'}" unless options[:extension]==false
        status = options.delete(:status) || 200
        url = if options.has_key?(:url)
          options[:url]
        else
          "https://this-is-my-test-shop.duodealer.com#{api_version.construct_api_path("#{endpoint}#{extension}")}"
        end

        stubbing = WebMock.stub_request(method, url)
        stubbing = stubbing.with(body: request_body) if request_body
        stubbing.to_return(
          body: body, status: status, headers: { content_type: "text/#{format}", content_length: 1 }.merge(options)
        )
      end

      def ar_version_before?(version_string)
        Gem::Version.new(ActiveResource::VERSION::STRING) < Gem::Version.new(version_string)
      end

      def ar_version_after?(version_string)
        Gem::Version.new(version_string) < Gem::Version.new(ActiveResource::VERSION::STRING)
      end
    end
  end
end
